==> am_mod_evt_0_2.zip: am_mod_evt_0_2/components/evt/template/barnraiser_01/manage.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>



<form action="index.php?amn=evt_manage" method="post" name="frm" id="id_frm">
<input type="hidden" name="event_id" value="<?php echo $event['event_id'];?>" />


<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_manage'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $event['event_title'];?></b><br />
					<?php echo $event['event_synopsis'];?><br />
				</p>
				
				<ul>
					<li><a href="index.php?amn=evt_edit&amp;event_id=<?php echo $event['event_id'];?>"><?php echo $lang['href_edit'];?></a></li>
				</ul>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_status'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
			<p><?php echo $lang['txt_status_intro']; ?></p>
			<hr />
				<select name="frm_status">
					<option value="<?php echo $config['event']['status']['live']; ?>"<?php if ($event['status_id'] == $config['event']['status']['live']) echo "selected=\"selected\""; ?>><?php echo $lang['txt_live']; ?></option>
					<option value="<?php echo $config['event']['status']['canceled']; ?>"<?php if ($event['status_id'] == $config['event']['status']['canceled']) echo "selected=\"selected\""; ?>><?php echo $lang['txt_cancel']; ?></option>
				</select>
				<p align="right">
					<input type="submit" value="<?php echo $lang['sub_change']; ?>" class="input_submit" name="submit_status" /><br />
				</p>
			</div>
		</div>
	</div>
			
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_ownership'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				
				<p>
					<?php echo $lang['txt_owner_intro'];?><br />
				</p>
				
				<?php
				if (isset($coordinators)) {
				?>
				<p>
					<label for="id_user_id"><?php echo $lang['txt_new_owner'];?></label>
					<select id="id_user_id" name="user_id" style="width:160px;">
						<?php
						foreach ($coordinators as $key => $i):
						?>
						<option value="<?php echo $i['user_id'];?>"><?php echo $i['identity_nic'];?></option>
						<?php
						endforeach;
						?>
					</select>
				</p>
				
				<hr />
					
				<p align="right">
					<input name="update_ownership" type="submit" class="input_submit" value="<?php echo $lang['sub_resign'];?>" /><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_tags'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $lang['txt_tags'];?></b><br />
					<?php
					if (isset($tags)) {
					$prnt = "";
					foreach($tags as $key => $i):
						$prnt .= $i['tag_body'] . "<sup><a href='index.php?amn=evt_manage&amp;event_id=" . $event['event_id'] . "&amp;edit_tag=" . $i['tag_id'] . "&amp;user_id=" . $i['item_id'] . "' style='text-decoration:none;'>&#43;</a></sup> ";
					endforeach;
					echo $prnt;
					}
					?>
				</p>
				
				<table cellspacing="1" cellpadding="0" border="0" width="100%">
					<tr>
						<td>
							<input type="hidden" name="tag_id" value="<?php if (isset($tag)) { echo $tag['tag_id'];}?>" />
							<input type="text" class="input1" name="tag_body" size="10" value="<?php if (isset($tag)) { echo $tag['tag_body'];}?>" /><br />
						</td>	
						<td nowrap="nowrap" align="right">
							<input type="submit" name="insert_tag" class="input_submit" style="font-size:60%;" value="<?php echo $lang['sub_ok']; ?>" /> 
							<input type="submit" name="delete_tag" class="input_submit" style="font-size:60%;" value="<?php echo $lang['sub_del']; ?>" /><br />
						</td>					
					</tr>				
				</table>
			</div>
		</div>
	</div>
</div>
</form>

==> am_mod_evt_0_4.zip: am_mod_evt_0_4/components/evt/template/barnraiser_01/manage.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>



<form action="index.php?amn=evt_manage" method="post" name="frm" id="id_frm">
<input type="hidden" name="event_id" value="<?php echo $event['event_id'];?>" />


<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_manage'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $event['event_title'];?></b><br />
					<?php echo $event['event_synopsis'];?><br />
				</p>
				
				<ul>
					<li><a href="index.php?amn=evt_edit&amp;event_id=<?php echo $event['event_id'];?>"><?php echo $lang['href_edit'];?></a></li>
				</ul>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_status'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
			<p><?php echo $lang['txt_status_intro']; ?></p>
			<hr />
				<select name="frm_status">
					<option value="<?php echo $config['event']['status']['live']; ?>"<?php if ($event['status_id'] == $config['event']['status']['live']) echo "selected=\"selected\""; ?>><?php echo $lang['txt_live']; ?></option>
					<option value="<?php echo $config['event']['status']['canceled']; ?>"<?php if ($event['status_id'] == $config['event']['status']['canceled']) echo "selected=\"selected\""; ?>><?php echo $lang['txt_cancel']; ?></option>
				</select>
				<p align="right">
					<input type="submit" value="<?php echo $lang['sub_change']; ?>" class="input_submit" name="submit_status" /><br />
				</p>
			</div>
		</div>
	</div>
			
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_ownership'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				
				<p>
					<?php echo $lang['txt_owner_intro'];?><br />
				</p>
				
				<?php
				if (isset($coordinators)) {
				?>
				<p>
					<label for="id_user_id"><?php echo $lang['txt_new_owner'];?></label>
					<select id="id_user_id" name="user_id" style="width:160px;">
						<?php
						foreach ($coordinators as $key => $i):
						?>
						<option value="<?php echo $i['user_id'];?>"><?php echo $i['identity_nic'];?></option>
						<?php
						endforeach;
						?>
					</select>
				</p>
				
				<hr />
					
				<p align="right">
					<input name="update_ownership" type="submit" class="input_submit" value="<?php echo $lang['sub_resign'];?>" /><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_tags'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $lang['txt_tags'];?></b><br />
					<?php
					if (isset($tags)) {
					$prnt = "";
					foreach($tags as $key => $i):
						$prnt .= $i['tag_body'] . "<sup><a href='index.php?amn=evt_manage&amp;event_id=" . $event['event_id'] . "&amp;edit_tag=" . $i['tag_id'] . "&amp;user_id=" . $i['item_id'] . "' style='text-decoration:none;'>&#43;</a></sup> ";
					endforeach;
					echo $prnt;
					}
					?>
				</p>
				
				<table cellspacing="1" cellpadding="0" border="0" width="100%">
					<tr>
						<td>
							<input type="hidden" name="tag_id" value="<?php if (isset($tag)) { echo $tag['tag_id'];}?>" />
							<input type="text" class="input1" name="tag_body" size="10" value="<?php if (isset($tag)) { echo $tag['tag_body'];}?>" /><br />
						</td>	
						<td nowrap="nowrap" align="right">
							<input type="submit" name="insert_tag" class="input_submit" style="font-size:60%;" value="<?php echo $lang['sub_ok']; ?>" /> 
							<input type="submit" name="delete_tag" class="input_submit" style="font-size:60%;" value="<?php echo $lang['sub_del']; ?>" /><br />
						</td>
					</tr>
				</table>
			</div>
		</div>
	</div>
</div>
</form>
